EXPORTS
	??0RNSmlDMCallbackSession@@QAE@XZ @ 1 NONAME ; RNSmlDMCallbackSession::RNSmlDMCallbackSession(void)
	??1RNSmlDMCallbackSession@@QAE@XZ @ 2 NONAME ; RNSmlDMCallbackSession::~RNSmlDMCallbackSession(void)
	?AddMappingInfoL@RNSmlDMCallbackSession@@QAEHKABVTDesC8@@0@Z @ 3 NONAME ; int RNSmlDMCallbackSession::AddMappingInfoL(unsigned long, class TDesC8 const &, class TDesC8 const &)
	?CheckAclL@RNSmlDMCallbackSession@@QAEHABVTDesC8@@W4TNSmlDmCmdType@@@Z @ 4 NONAME ; int RNSmlDMCallbackSession::CheckAclL(class TDesC8 const &, enum TNSmlDmCmdType)
	?CheckDynamicAclL@RNSmlDMCallbackSession@@QAEHABVTDesC8@@W4TNSmlDmCmdType@@PAVCNSmlDmMgmtTree@@@Z @ 5 NONAME ; int RNSmlDMCallbackSession::CheckDynamicAclL(class TDesC8 const &, enum TNSmlDmCmdType, class CNSmlDmMgmtTree *)
	?Close@RNSmlDMCallbackSession@@QAEXXZ @ 6 NONAME ; void RNSmlDMCallbackSession::Close(void)
	?CommitAtomic@RNSmlDMCallbackSession@@QAEHXZ @ 7 NONAME ; int RNSmlDMCallbackSession::CommitAtomic(void)
	?Connect@RNSmlDMCallbackSession@@QAEHXZ @ 8 NONAME ; int RNSmlDMCallbackSession::Connect(void)
	?DefaultACLsToChildrenL@RNSmlDMCallbackSession@@QAEHABVTDesC8@@AAVCBufBase@@@Z @ 9 NONAME ; int RNSmlDMCallbackSession::DefaultACLsToChildrenL(class TDesC8 const &, class CBufBase &)
	?DefaultACLsToServerL@RNSmlDMCallbackSession@@QAEHABVTDesC8@@@Z @ 10 NONAME ; int RNSmlDMCallbackSession::DefaultACLsToServerL(class TDesC8 const &)
	?DeleteAclL@RNSmlDMCallbackSession@@QAEHABVTDesC8@@@Z @ 11 NONAME ; int RNSmlDMCallbackSession::DeleteAclL(class TDesC8 const &)
	?EraseServerIdL@RNSmlDMCallbackSession@@QAEHABVTDesC8@@@Z @ 12 NONAME ; int RNSmlDMCallbackSession::EraseServerIdL(class TDesC8 const &)
	?GetAclL@RNSmlDMCallbackSession@@QAEHABVTDesC8@@AAVCBufBase@@H@Z @ 13 NONAME ; int RNSmlDMCallbackSession::GetAclL(class TDesC8 const &, class CBufBase &, int)
	?GetLuidAllocL@RNSmlDMCallbackSession@@QAEPAVHBufC8@@KABVTDesC8@@@Z @ 14 NONAME ; class HBufC8 * RNSmlDMCallbackSession::GetLuidAllocL(unsigned long, class TDesC8 const &)
	?GetUriSegListL@RNSmlDMCallbackSession@@QAEXKABVTDesC8@@AAV?$CArrayFixFlat@UTSmlDmMappingInfo@@@@@Z @ 15 NONAME ; void RNSmlDMCallbackSession::GetUriSegListL(unsigned long, class TDesC8 const &, class CArrayFixFlat<struct TSmlDmMappingInfo> &)
	?RemoveMappingInfoL@RNSmlDMCallbackSession@@QAEHKABVTDesC8@@H@Z @ 16 NONAME ; int RNSmlDMCallbackSession::RemoveMappingInfoL(unsigned long, class TDesC8 const &, int)
	?RenameMappingL@RNSmlDMCallbackSession@@QAEHKABVTDesC8@@0@Z @ 17 NONAME ; int RNSmlDMCallbackSession::RenameMappingL(unsigned long, class TDesC8 const &, class TDesC8 const &)
	?ResourceCount@RNSmlDMCallbackSession@@QAEHXZ @ 18 NONAME ; int RNSmlDMCallbackSession::ResourceCount(void)
	?RollbackAtomic@RNSmlDMCallbackSession@@QAEHXZ @ 19 NONAME ; int RNSmlDMCallbackSession::RollbackAtomic(void)
	?SetServerL@RNSmlDMCallbackSession@@QAEXABVTDesC8@@@Z @ 20 NONAME ; void RNSmlDMCallbackSession::SetServerL(class TDesC8 const &)
	?StartAtomic@RNSmlDMCallbackSession@@QAEHXZ @ 21 NONAME ; int RNSmlDMCallbackSession::StartAtomic(void)
	?UpdateAclL@RNSmlDMCallbackSession@@QAEHABVTDesC8@@0@Z @ 22 NONAME ; int RNSmlDMCallbackSession::UpdateAclL(class TDesC8 const &, class TDesC8 const &)
	?UpdateMappingInfoL@RNSmlDMCallbackSession@@QAEXKABVTDesC8@@AAVCBufBase@@@Z @ 23 NONAME ; void RNSmlDMCallbackSession::UpdateMappingInfoL(unsigned long, class TDesC8 const &, class CBufBase &)

